@@ -22,9 +22,12 @@
 
 #include <map>
 #include <string>
+#include <boost/shared_ptr.hpp>
+#include "my_sstream.h"
 
 using std::map;
 using std::string;
+using std::ostringstream;
 
 class ColorMap : public map<string, string>
 {
@@ -41,6 +44,16 @@ class ColorMap : public map<string, string>
     else
       return it->second;
   }
+  const string toString() const
+  {
+    ostringstream s;
+    for (const_iterator it = begin(); it != end(); ++it)
+      s << "[" << it->first << "]=" << it->second << "\n";
+    s << "default=" << default_color;
+    return s.str();
+  }
 };
 
+typedef boost::shared_ptr<ColorMap> ColorMapPtr;
+
 #endif // COLORMAP_H
