@@ -21,17 +21,23 @@
 
 #include "generatorfactory.h"
 
-#include "tags.h"
+#include "styles.h"
 #include "keys.h"
 #include "textgenerator.h"
 #include "textstyles.h"
 #include "textstylebuilder.h"
+#include "refgeneratormap.h"
 
 // global
 #include "maingeneratormap.h"
 
-GeneratorFactory::GeneratorFactory(TextStylesPtr styles, Tags *tgs) :
-  textStyles(styles), tags(tgs)
+GeneratorFactory::GeneratorFactory(TextStylesPtr tstyles, Styles *sts,
+    PreFormatter *pf,
+    bool gen_ref,
+    const string &_ctags_file, RefPosition position) :
+  textStyles(tstyles), styles(sts), preformatter(pf),
+  generate_references(gen_ref),
+  ctags_file(_ctags_file), refposition(position)
 {
 }
 
@@ -44,7 +50,11 @@ GeneratorFactory::~ GeneratorFactory()
 GeneratorMap *
 GeneratorFactory::createGeneratorMap()
 {
-  return new GeneratorMap;
+  if (generate_references)
+    return new RefGeneratorMap(preformatter, ctags_file,
+      textStyles->refstyle, refposition);
+
+  return new GeneratorMap(preformatter);
 }
 
 void
@@ -53,7 +63,7 @@ GeneratorFactory::createGenerators()
   generatormap = createGeneratorMap();
 
   TextGenerator *text_gen;
-  for (Tags::const_iterator it = tags->begin(); it != tags->end(); ++it)
+  for (Styles::const_iterator it = styles->begin(); it != styles->end(); ++it)
     {
       text_gen = createGenerator(*it);
       generatormap->addGenerator((*it)->GetName(), text_gen);
@@ -76,7 +86,7 @@ GeneratorFactory::createDefaultGenerator()
 TextGenerator *
 GeneratorFactory::createGenerator( const string &key )
 {
-  const Tag *tag = tags->GetTag( key ) ;
+  const Style *tag = styles->GetStyle( key ) ;
 
   if ( ! tag ) // no options
     return new TextGenerator ;
@@ -85,7 +95,7 @@ GeneratorFactory::createGenerator( const string &key )
 }
 
 TextGenerator *
-GeneratorFactory::createGenerator( const Tag *tag )
+GeneratorFactory::createGenerator( const Style *tag )
 {
   if (! textStyles->onestyle.empty())
     return new TextGenerator(textStyles->onestyle.subst_style(tag->GetName()));
@@ -94,9 +104,9 @@ GeneratorFactory::createGenerator( const Tag *tag )
 
   textStyleBuilder.start();
 
-  TagStylesPtr tagStyles = tag->getTagStyles();
+  StyleConstantsPtr tagStyles = tag->getStyleConstants();
   if (tagStyles.get()) {
-    for (TagStylesIterator it = tagStyles->begin(); it != tagStyles->end(); ++it) {
+    for (StyleConstantsIterator it = tagStyles->begin(); it != tagStyles->end(); ++it) {
       switch( *it ){
         case ISBOLD:
           textStyleBuilder.add(textStyles->bold);
@@ -113,6 +123,9 @@ GeneratorFactory::createGenerator( const Tag *tag )
         case ISNOTFIXED:
           textStyleBuilder.add(textStyles->notfixed);
           break;
+        case ISNOREF:
+          generatormap->addNoReference(tag->GetName());
+          break;
       }
     }
   }
@@ -121,8 +134,8 @@ GeneratorFactory::createGenerator( const Tag *tag )
   if ( color.size () )
   {
     string c;
-    if ( color[0] == '#' && color.size () == 7 )
-      c = color; // FIXME: handle direct colors not only for HTML
+    if ( color[0] == '"' && color[color.size()-1] == '"')
+      c = color.substr(1, color.size()-2);
     else
       c = textStyles->colorMap->getColor (color);
 
