@@ -19,7 +19,7 @@
 
 using namespace std;
 
-boost::regex assoc_exp("[[:blank:]]*([^[:blank:]]+)[[:blank:]]*=[[:blank:]]*([^[:blank:]]+)[[:blank:]]*|([[:space:]]+)");
+boost::regex assoc_exp("[[:blank:]]*([^[:blank:]]+)[[:blank:]]*=[[:blank:]]*([^[:blank:]\\r]+)[[:blank:]\\r]*|([[:space:]]+)");
 
 LangMap::LangMap(const string &path, const string &filename)
 {
