@@ -1,7 +1,7 @@
 //
 // C++ Interface: langmap
 //
-// Description: 
+// Description:
 //
 //
 // Author: Lorenzo Bettini <bettini@gnu.org>, (C) 2004
@@ -14,6 +14,7 @@
 
 #include <string>
 #include <map>
+#include <boost/shared_ptr.hpp>
 
 /**
 map a file extension to a language definition
@@ -23,18 +24,21 @@ map a file extension to a language definition
 class LangMap
 {
   typedef std::map<std::string, std::string> Map;
-  
+
   Map langmap;
-  
+
 public:
+  LangMap() {}
   LangMap(const std::string &path, const std::string &filename);
 
   ~LangMap();
-  
+
   void print();
   const std::string &get_file(const std::string &lang) {
     return langmap[lang];
   }
 };
 
+typedef boost::shared_ptr<LangMap> LangMapPtr;
+
 #endif
