@@ -20,9 +20,12 @@
 
 using namespace std;
 
-LineOutputGenerator::LineOutputGenerator(OutputBuffer& buff, ostream& os,
-    TextStyle *anch, bool genref, const string &prefix):
-  OutputGenerator(buff, os), generate_ref(genref && ! anch->empty()),
+static SubstitutionMapping substitutionmapping;
+
+LineOutputGenerator::LineOutputGenerator(ostream& os,
+    TextStyle *anch, bool genref, const string &prefix,
+    const std::string &line_pref):
+  OutputGenerator(os, line_pref), generate_ref(genref && ! anch->empty()),
   anchor(anch), anchor_line_prefix(prefix), line_num(1)
 {
   line_num_generator = generatormap->getGenerator("linenum");
@@ -34,7 +37,7 @@ LineOutputGenerator::~LineOutputGenerator()
 }
 
 
-void LineOutputGenerator::generate_line(const string& line)
+void LineOutputGenerator::generate_line(const string &line)
 {
   generate_line_info();
   ++line_num;
@@ -61,7 +64,9 @@ LineOutputGenerator::generate_line_info()
     ostringstream line_n;
     line_n << anchor_line_prefix << line_num;
     sout.str("");
-    sout << anchor->output(line_str, line_n.str());
+    substitutionmapping["$text"] = line_str;
+    substitutionmapping["$linenum"] = line_n.str();
+    sout << anchor->output(substitutionmapping);
     line_str = sout.str();
   }
 
