@@ -32,13 +32,14 @@ private:
   TextGenerator *line_num_generator;
 
 public:
-    LineOutputGenerator(OutputBuffer& buff, std::ostream& os,
-      TextStyle *anch, bool genref, const std::string &prefix);
+    LineOutputGenerator(std::ostream& os,
+      TextStyle *anch, bool genref, const std::string &prefix,
+      const std::string &line_pref);
 
     ~LineOutputGenerator();
 
 protected:
-    virtual void generate_line(const std::string& line);
+  virtual void generate_line(const std::string &line);
     virtual void reset();
 
     virtual void generate_line_info();
