@@ -67,8 +67,10 @@
      UNDERLINE = 260,
      FIXED = 261,
      NOTFIXED = 262,
-     KEY = 263,
-     COLOR = 264
+     NOREF = 263,
+     KEY = 264,
+     COLOR = 265,
+     STRINGDEF = 266
    };
 #endif
 #define BOLD 258
@@ -76,8 +78,10 @@
 #define UNDERLINE 260
 #define FIXED 261
 #define NOTFIXED 262
-#define KEY 263
-#define COLOR 264
+#define NOREF 263
+#define KEY 264
+#define COLOR 265
+#define STRINGDEF 266
 
 
 
@@ -111,11 +115,11 @@
 
 #include "my_sstream.h"
 
-#include "tags.h"
+#include "styles.h"
 #include "colors.h"
 #include "keys.h"
 #include "messages.h"
-#include "parsetags.h"
+#include "parsestyles.h"
 #include "fileutil.h"
 
 using std::cerr;
@@ -125,8 +129,8 @@ static void yyerror( char *s ) ;
 
 int line = 1 ;
 
-static void add_tag(Tags *tags, Tag *t);
-static Tags *parsed_tags = 0;
+static void add_style(Styles *styles, Style *t);
+static Styles *parsed_styles = 0;
 
 extern int opsc_lex() ;
 extern FILE *opsc_in ;
@@ -151,13 +155,13 @@ extern FILE *opsc_in ;
 typedef union YYSTYPE {
   int tok ; /* command */
   const std::string * string ; /* string : id, ... */
-  TagStyle flag ;
-  Tag *tag ;
-  Tags *tags ;
-  TagStyles *tagstyles;
+  StyleConstant flag ;
+  Style *style ;
+  Styles *styles ;
+  StyleConstants *styleconstants;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 161 "optparser.cc"
+#line 165 "optparser.cc"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -169,7 +173,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 173 "optparser.cc"
+#line 177 "optparser.cc"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -273,22 +277,22 @@ union yyalloc
 #endif
 
 /* YYFINAL -- State number of the termination state. */
-#define YYFINAL  6
+#define YYFINAL  8
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   11
+#define YYLAST   13
 
 /* YYNTOKENS -- Number of terminals. */
-#define YYNTOKENS  12
+#define YYNTOKENS  14
 /* YYNNTS -- Number of nonterminals. */
-#define YYNNTS  8
+#define YYNNTS  9
 /* YYNRULES -- Number of rules. */
-#define YYNRULES  15
+#define YYNRULES  19
 /* YYNRULES -- Number of states. */
-#define YYNSTATES  20
+#define YYNSTATES  23
 
 /* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
 #define YYUNDEFTOK  2
-#define YYMAXUTOK   264
+#define YYMAXUTOK   266
 
 #define YYTRANSLATE(YYX) 						\
   ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
@@ -300,8 +304,8 @@ static const unsigned char yytranslate[] =
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-       2,     2,     2,     2,    11,     2,     2,     2,     2,     2,
-       2,     2,     2,     2,     2,     2,     2,     2,     2,    10,
+       2,     2,     2,     2,    13,     2,     2,     2,     2,     2,
+       2,     2,     2,     2,     2,     2,     2,     2,     2,    12,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -322,7 +326,7 @@ static const unsigned char yytranslate[] =
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
-       5,     6,     7,     8,     9
+       5,     6,     7,     8,     9,    10,    11
 };
 
 #if YYDEBUG
@@ -331,23 +335,24 @@ static const unsigned char yytranslate[] =
 static const unsigned char yyprhs[] =
 {
        0,     0,     3,     5,     8,    10,    11,    17,    18,    20,
-      24,    26,    28,    30,    32,    34
+      22,    23,    25,    29,    31,    33,    35,    37,    39,    41
 };
 
 /* YYRHS -- A `-1'-separated list of the rules' RHS. */
 static const yysigned_char yyrhs[] =
 {
-      13,     0,    -1,    14,    -1,    14,    15,    -1,    15,    -1,
-      -1,     8,     9,    16,    17,    10,    -1,    -1,    18,    -1,
-      18,    11,    19,    -1,    19,    -1,     3,    -1,     4,    -1,
-       5,    -1,     6,    -1,     7,    -1
+      15,     0,    -1,    16,    -1,    16,    17,    -1,    17,    -1,
+      -1,     9,    19,    18,    20,    12,    -1,    -1,    10,    -1,
+      11,    -1,    -1,    21,    -1,    21,    13,    22,    -1,    22,
+      -1,     3,    -1,     4,    -1,     5,    -1,     6,    -1,     7,
+      -1,     8,    -1
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,    69,    69,    72,    73,    77,    76,    90,    91,    94,
-      95,    98,    99,   100,   101,   102
+       0,    70,    70,    73,    74,    78,    77,    96,    97,    98,
+     101,   102,   105,   106,   109,   110,   111,   112,   113,   114
 };
 #endif
 
@@ -357,8 +362,9 @@ static const unsigned char yyrline[] =
 static const char *const yytname[] =
 {
   "$end", "error", "$undefined", "BOLD", "ITALICS", "UNDERLINE", "FIXED",
-  "NOTFIXED", "KEY", "COLOR", "';'", "','", "$accept", "globaltags",
-  "options", "option", "@1", "stylevalues", "values", "value", 0
+  "NOTFIXED", "NOREF", "KEY", "COLOR", "STRINGDEF", "';'", "','",
+  "$accept", "globalstyles", "options", "option", "@1", "color",
+  "stylevalues", "values", "value", 0
 };
 #endif
 
@@ -368,22 +374,22 @@ static const char *const yytname[] =
 static const unsigned short int yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
-      59,    44
+     265,   266,    59,    44
 };
 # endif
 
 /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
 static const unsigned char yyr1[] =
 {
-       0,    12,    13,    14,    14,    16,    15,    17,    17,    18,
-      18,    19,    19,    19,    19,    19
+       0,    14,    15,    16,    16,    18,    17,    19,    19,    19,
+      20,    20,    21,    21,    22,    22,    22,    22,    22,    22
 };
 
 /* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
 static const unsigned char yyr2[] =
 {
-       0,     2,     1,     2,     1,     0,     5,     0,     1,     3,
-       1,     1,     1,     1,     1,     1
+       0,     2,     1,     2,     1,     0,     5,     0,     1,     1,
+       0,     1,     3,     1,     1,     1,     1,     1,     1,     1
 };
 
 /* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
@@ -391,29 +397,31 @@ static const unsigned char yyr2[] =
    means the default is an error.  */
 static const unsigned char yydefact[] =
 {
-       0,     0,     0,     2,     4,     5,     1,     3,     7,    11,
-      12,    13,    14,    15,     0,     8,    10,     6,     0,     9
+       0,     7,     0,     2,     4,     8,     9,     5,     1,     3,
+      10,    14,    15,    16,    17,    18,    19,     0,    11,    13,
+       6,     0,    12
 };
 
 /* YYDEFGOTO[NTERM-NUM]. */
 static const yysigned_char yydefgoto[] =
 {
-      -1,     2,     3,     4,     8,    14,    15,    16
+      -1,     2,     3,     4,    10,     7,    17,    18,    19
 };
 
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
-#define YYPACT_NINF -9
+#define YYPACT_NINF -10
 static const yysigned_char yypact[] =
 {
-      -2,    -4,     7,    -2,    -9,    -9,    -9,    -9,    -3,    -9,
-      -9,    -9,    -9,    -9,    -1,     0,    -9,    -9,    -3,    -9
+      -1,    -4,     9,    -1,   -10,   -10,   -10,   -10,   -10,   -10,
+      -3,   -10,   -10,   -10,   -10,   -10,   -10,    -2,     0,   -10,
+     -10,    -3,   -10
 };
 
 /* YYPGOTO[NTERM-NUM].  */
 static const yysigned_char yypgoto[] =
 {
-      -9,    -9,    -9,     5,    -9,    -9,    -9,    -8
+     -10,   -10,   -10,     8,   -10,   -10,   -10,   -10,    -9
 };
 
 /* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
@@ -423,22 +431,23 @@ static const yysigned_char yypgoto[] =
 #define YYTABLE_NINF -1
 static const unsigned char yytable[] =
 {
-       9,    10,    11,    12,    13,     5,     1,     6,     7,    17,
-      19,    18
+      11,    12,    13,    14,    15,    16,     5,     6,     1,     8,
+      20,     9,    22,    21
 };
 
 static const unsigned char yycheck[] =
 {
-       3,     4,     5,     6,     7,     9,     8,     0,     3,    10,
-      18,    11
+       3,     4,     5,     6,     7,     8,    10,    11,     9,     0,
+      12,     3,    21,    13
 };
 
 /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
    symbol of state STATE-NUM.  */
 static const unsigned char yystos[] =
 {
-       0,     8,    13,    14,    15,     9,     0,    15,    16,     3,
-       4,     5,     6,     7,    17,    18,    19,    10,    11,    19
+       0,     9,    15,    16,    17,    10,    11,    19,     0,    17,
+      18,     3,     4,     5,     6,     7,     8,    20,    21,    22,
+      12,    13,    22
 };
 
 #if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
@@ -1050,83 +1059,113 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 69 "./optparser.yy"
-    { parsed_tags = yyvsp[0].tags; }
+#line 70 "./optparser.yy"
+    { parsed_styles = yyvsp[0].styles; }
     break;
 
   case 3:
-#line 72 "./optparser.yy"
-    { add_tag( yyvsp[-1].tags, yyvsp[0].tag ) ; }
+#line 73 "./optparser.yy"
+    { add_style( yyvsp[-1].styles, yyvsp[0].style ) ; }
     break;
 
   case 4:
-#line 73 "./optparser.yy"
-    { yyval.tags = new Tags() ; yyval.tags->AddTag( yyvsp[0].tag ) ;  }
+#line 74 "./optparser.yy"
+    { yyval.styles = new Styles() ; yyval.styles->AddStyle( yyvsp[0].style ) ;  }
     break;
 
   case 5:
-#line 77 "./optparser.yy"
+#line 78 "./optparser.yy"
     {
-                 printMessage( *yyvsp[-1].string ) ;
-                 printMessage( *yyvsp[0].string ) ;
+                 printMessage_noln( *yyvsp[-1].string ) ;
+                 printMessage_noln( ": " ) ;
+                 printMessage_noln( (yyvsp[0].string ? *yyvsp[0].string : "") ) ;
              }
     break;
 
   case 6:
-#line 82 "./optparser.yy"
+#line 84 "./optparser.yy"
     {
-               yyval.tag = new Tag( *yyvsp[-4].string, *yyvsp[-3].string ) ;
-               yyval.tag->setStyles(TagStylesPtr(yyvsp[-1].tagstyles)) ;
+               if (yyvsp[-3].string)
+                  yyval.style = new Style( *yyvsp[-4].string, *yyvsp[-3].string ) ;
+               else
+                  yyval.style = new Style( *yyvsp[-4].string ) ;
+               yyval.style->setStyles(StyleConstantsPtr(yyvsp[-1].styleconstants)) ;
                delete yyvsp[-4].string;
-               delete yyvsp[-3].string;
+               if (yyvsp[-3].string)
+                delete yyvsp[-3].string;
              }
     break;
 
   case 7:
-#line 90 "./optparser.yy"
-    { yyval.tagstyles = 0 ; printMessage( " (no options) " ) ; }
+#line 96 "./optparser.yy"
+    { yyval.string = 0; }
+    break;
+
+  case 8:
+#line 97 "./optparser.yy"
+    { yyval.string = yyvsp[0].string;}
     break;
 
   case 9:
-#line 94 "./optparser.yy"
-    { yyval.tagstyles = yyvsp[-2].tagstyles; yyval.tagstyles->push_back(yyvsp[0].flag) ; }
+#line 98 "./optparser.yy"
+    { yyval.string = yyvsp[0].string; }
     break;
 
   case 10:
-#line 95 "./optparser.yy"
-    { yyval.tagstyles = new TagStyles; yyval.tagstyles->push_back(yyvsp[0].flag); }
+#line 101 "./optparser.yy"
+    { yyval.styleconstants = 0 ; printMessage( " (no options) " ) ; }
     break;
 
   case 11:
-#line 98 "./optparser.yy"
-    { printMessage( " - bold" ) ; yyval.flag = ISBOLD ; }
+#line 102 "./optparser.yy"
+    { yyval.styleconstants = yyvsp[0].styleconstants; printMessage(""); }
     break;
 
   case 12:
-#line 99 "./optparser.yy"
-    { printMessage( " - italics" ) ; yyval.flag = ISITALIC ; }
+#line 105 "./optparser.yy"
+    { yyval.styleconstants = yyvsp[-2].styleconstants; yyval.styleconstants->push_back(yyvsp[0].flag) ; }
     break;
 
   case 13:
-#line 100 "./optparser.yy"
-    { printMessage( " - underline" ) ; yyval.flag = ISUNDERLINE ; }
+#line 106 "./optparser.yy"
+    { yyval.styleconstants = new StyleConstants; yyval.styleconstants->push_back(yyvsp[0].flag); }
     break;
 
   case 14:
-#line 101 "./optparser.yy"
-    { printMessage( " - fixed" ) ; yyval.flag = ISFIXED ; }
+#line 109 "./optparser.yy"
+    { printMessage_noln( " - bold" ) ; yyval.flag = ISBOLD ; }
     break;
 
   case 15:
-#line 102 "./optparser.yy"
-    { printMessage( " - notfixed" ) ; yyval.flag = ISNOTFIXED ; }
+#line 110 "./optparser.yy"
+    { printMessage_noln( " - italics" ) ; yyval.flag = ISITALIC ; }
+    break;
+
+  case 16:
+#line 111 "./optparser.yy"
+    { printMessage_noln( " - underline" ) ; yyval.flag = ISUNDERLINE ; }
+    break;
+
+  case 17:
+#line 112 "./optparser.yy"
+    { printMessage_noln( " - fixed" ) ; yyval.flag = ISFIXED ; }
+    break;
+
+  case 18:
+#line 113 "./optparser.yy"
+    { printMessage_noln( " - notfixed" ) ; yyval.flag = ISNOTFIXED ; }
+    break;
+
+  case 19:
+#line 114 "./optparser.yy"
+    { printMessage_noln( " - noref" ) ; yyval.flag = ISNOREF ; }
     break;
 
 
     }
 
 /* Line 1010 of yacc.c.  */
-#line 1130 "optparser.cc"
+#line 1169 "optparser.cc"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1351,13 +1390,13 @@ yyreturn:
 }
 
 
-#line 105 "./optparser.yy"
+#line 117 "./optparser.yy"
 
 
 string current_file;
 
-Tags *
-parseTags(const string &path, const string &name)
+Styles *
+parseStyles(const string &path, const string &name)
 {
   // opens the file for yylex
   opsc_in = open_data_file_stream(path, name);
@@ -1367,27 +1406,33 @@ parseTags(const string &path, const string &name)
   printMessage_noln( "Parsing ", cerr ) ;
   printMessage_noln (current_file, cerr);
   printMessage( " file ...", cerr ) ;
-  parsed_tags = 0;
+  parsed_styles = 0;
   yyparse() ;
   printMessage( "Parsing done!", cerr ) ;
   fclose(opsc_in);
-  return parsed_tags;
+  return parsed_styles;
 }
 
 void
 yyerror( char *s )
 {
-  ostringstream str ;
-  str << current_file << ":" << line << ": " << s << ", in option declaration";
-  printError( str.str().c_str(), cerr ) ;
+  parseStyleError(s);
   exit(EXIT_FAILURE);
 }
 
-void
-add_tag(Tags *tags, Tag *t)
+void parseStyleError(const std::string &error)
 {
-  if (! tags->AddTag(t))
+  ostringstream str ;
+  str << current_file << ":" << line << ": " << error;
+  printError( str.str(), cerr ) ;
+}
+
+void
+add_style(Styles *styles, Style *t)
+{
+  if (! styles->AddStyle(t))
   {
     yyerror("already defined");
   }
 }
+
