@@ -4,25 +4,25 @@
 //      Derived Pretranslator to convert tabs to spaces before HTML generation
 //
 //      Don Stauffer Revision: June 2003
-//      Lorenzo Bettini Revision: November 2004, mostly rewritten
+//      Lorenzo Bettini Revision: November 2004, mostly completely rewritten
 //****************************************************************************//
 #ifndef	srcUntabifier_H
 #define	srcUntabifier_H
 
-#include "textformatter.h"
+#include "preformatter.h"
 
 using std::string;
 
-class Untabifier : public TextFormatter
+class Untabifier : public PreFormatter
 {
  public:
 
-  Untabifier (int nSpacesPerTab, TextFormatterPtr f = TextFormatterPtr()) :
-    TextFormatter(f), nSpacesPerTab_ (nSpacesPerTab), n_ (0)
+  Untabifier (int nSpacesPerTab, PreFormatterPtr f = PreFormatterPtr()) :
+    PreFormatter(f), nSpacesPerTab_ (nSpacesPerTab), n_ (0)
     {
     }
 
-  virtual const string preformat( const std::string &text );
+  virtual const string doPreformat( const std::string &text );
 
  private:
 
