@@ -19,6 +19,7 @@ class TextFormatter;
 #include <string>
 #include <stack>
 #include <boost/shared_ptr.hpp>
+#include "fileinfo.h"
 
 /**
 the class that actually performs regular expression processing
@@ -29,6 +30,7 @@ class RegExpEngine
 {
   protected:
     RegExpStatePtr currentstate, initial_state;
+    FileInfo *fileinfo;
 
   private:
     TextFormatter *formatter;
@@ -37,12 +39,14 @@ class RegExpEngine
 
   protected:
     virtual void enterState(int index);
-    virtual void exitState();
+    virtual void exitState(int level);
     virtual void exitAll();
     virtual void format(int index, const std::string &s);
 
 public:
-  RegExpEngine(RegExpStatePtr v, TextFormatter *pre) : currentstate(v), formatter(pre) {}
+  RegExpEngine(RegExpStatePtr v, TextFormatter *pre, FileInfo *f) :
+    currentstate(v), fileinfo(f), formatter(pre)
+    {}
 
   virtual ~RegExpEngine();
 
