@@ -18,8 +18,10 @@
 
 using namespace std;
 
-RegExpFormatter::RegExpFormatter(const string &el, RegExpStatePtr r, bool exit, bool all) :
-    elem(el), exit_state(exit), exit_all(all), next_state(r)
+int RegExpState::global_id = 1;
+
+RegExpFormatter::RegExpFormatter(const string &el, RegExpStatePtr r, int exit, bool all) :
+    elem(el), exit_state_level(exit), exit_all(all), next_state(r)
 {
 }
 
@@ -37,10 +39,16 @@ RegExpStatePtr RegExpFormatter::getNextState() const
   return next;
 }
 
+/**
+ * Return the formatter associated to the passed index.
+ * If the index is negative, it returns the default formatter.
+ * @param index
+ * @return
+ */
 const string &
 RegExpState::get_elem(int index)
 {
-  return formatters[(index<0 ? current_formatter : index)]->elem;
+  return formatters[(index<0 ? 0 : index)]->elem;
 }
 
 void
@@ -69,7 +77,7 @@ RegExpState::freeze() throw(boost::bad_expression)
 }
 
 void
-RegExpState::add_normal_formatter(RegExpFormatterPtr f)
+RegExpState::set_default_formatter(RegExpFormatterPtr f)
 {
   formatters[0] = f;
 }
