@@ -191,6 +191,13 @@ StartApp::start(int argc, char * argv[])
   printMessage( PACKAGE ) ;
   printMessage( VERSION ) ;
   printMessage( argv[0] ) ;
+  
+  if (verbose) {
+    printMessage("command line arguments: ");
+    for (int i = 0; i < argc; ++i) {
+      printMessage(argv[i]);
+    }    
+  }
 
   /*
     the starting default path to search for files is computed at
@@ -216,7 +223,6 @@ StartApp::start(int argc, char * argv[])
 
   if (args_info.show_regex_given) {
     if (LangDefLoader::show_regex(data_dir, args_info.show_regex_arg)) {
-      cout << "OK" << endl;
       return(EXIT_SUCCESS);
     }
 
@@ -479,12 +485,14 @@ StartApp::processFile(const string &inputFileName, const string &outputFileName,
       return EXIT_FAILURE ;
     }
     deleteOStream = true;
+    printMessage("output file: " + inputFileName);
   }
 
   if (inputFileName.size())
     {
       unsigned int lines = get_line_count (inputFileName);
-
+      printMessage("input file: " + inputFileName);
+      
       line_num_digit = 0;
       while (lines)
         {
